@@ -62,7 +62,10 @@ class Freebox(IPlugin):
 					log.msg("*************  'idx_sec'] <> 1 ****************")
 					# séparation de rs['idx'], nombre   len(maliste)
 	# ###   140826			i = 1
-					while i <= int(rs['idx_sec']): 
+	# ###   140826			while i <= int(rs['idx_sec']):
+#
+# 
+					for i in range (1, int(rs['idx_sec'])):
 		#				if rs['idx'][i - rang] == '|':
 						rangs.append(rang)
 						log.msg(" rang  :  %s" % (rangs)
